[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/1.1.2...1.1.3)

### Fixes

- Fixed issues in GitHub workflows. [c900001](https://github.com/callowayproject/bump-my-version/commit/c9000019f851038a18a989c8336afc216255cd7f)
    
- Fixes for CalVer auto_increment behavior. [a034d5f](https://github.com/callowayproject/bump-my-version/commit/a034d5fc9f99d4c06f8e98a8016536cc55df5ed2)
    
  If `auto_increment` is explicitly set, the value is kept. Otherwise, it is set to `True`.

  Introduced new tests to verify CalVer component behavior with and without auto-increment enabled.
### Other

- [pre-commit.ci] pre-commit autoupdate. [9cb5598](https://github.com/callowayproject/bump-my-version/commit/9cb55989cf6425aae7aaa4568f1247571357f6fb)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.11.8 → v0.11.9](https://github.com/astral-sh/ruff-pre-commit/compare/v0.11.8...v0.11.9)

- [pre-commit.ci] pre-commit autoupdate. [1fa2a60](https://github.com/callowayproject/bump-my-version/commit/1fa2a60dfd02cd095d2fbd3573d4ef154c0c022c)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.11.7 → v0.11.8](https://github.com/astral-sh/ruff-pre-commit/compare/v0.11.7...v0.11.8)

- [pre-commit.ci] auto fixes from pre-commit.com hooks. [f0df17d](https://github.com/callowayproject/bump-my-version/commit/f0df17d23cc94fc6002cd248d569171402dd39c6)
    
  for more information, see https://pre-commit.ci
- [pre-commit.ci] pre-commit autoupdate. [5d0dc39](https://github.com/callowayproject/bump-my-version/commit/5d0dc39af06c6436940195ca7ec5a74f42162d7d)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.11.6 → v0.11.7](https://github.com/astral-sh/ruff-pre-commit/compare/v0.11.6...v0.11.7)

- [pre-commit.ci] pre-commit autoupdate. [efe46e6](https://github.com/callowayproject/bump-my-version/commit/efe46e6562ac6c0a73df001a6713710c5afd0e81)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.11.4 → v0.11.6](https://github.com/astral-sh/ruff-pre-commit/compare/v0.11.4...v0.11.6)

### Updates

- Update movable-version-tags.md. [16bea0c](https://github.com/callowayproject/bump-my-version/commit/16bea0c960dd08c89df3e501ff2351abef1ceb6c)
    
- Update movable-version-tags.md. [27cc579](https://github.com/callowayproject/bump-my-version/commit/27cc579df2f0f835ef8fb770357e5d6c27e9c9ff)
    
  The current documentation regarding moveable tags seems incorrect.
